@@ -2,11 +2,27 @@ package PrintEnv;
 
 require 5.005;
 use strict;
-use Apache::Constants qw(:common);
 use Data::Dumper;
 
 use vars qw($VERSION);
-$VERSION = '0.1';
+$VERSION = '0.2';
+
+use mod_perl;
+use constant MP2 => ($mod_perl::VERSION >= 1.99);
+
+BEGIN {
+	# Test mod_perl version and use the appropriate components
+	if (MP2) {
+		require Apache::Const;
+		Apache::Const->import(-compile => qw(OK));
+		require Apache::RequestRec;
+		require Apache::RequestIO;
+	}
+	else {
+		require Apache::Constants;
+		Apache::Constants->import(qw(OK));
+	}
+}
 
 sub handler {
 	my $r = shift;
@@ -25,17 +41,17 @@ EOM
 #	$str .= HashVariables($session,'<H2>Session Dump</H2>');
 	$str .= HashVariables(\%INC,'<H2>%INC</H2>');
 	$str .= HashVariables($r->subprocess_env,'<H2>Environment variables</H2>');
-	$str .= HashVariables({$r->headers_in()},'<H2>HTTP request headers</H2>');
+	$str .= HashVariables(MP2 ? $r->headers_in() : { $r->headers_in() },'<H2>HTTP request headers</H2>');
 	$str .= "</BODY>\n</HTML>";
 	
 	# set session value
 	$$session{rand()} = rand;
 
-   # Output code to client
-   $r->content_type('text/html'); 
-   $r->send_http_header;
+	# Output code to client
+   $r->content_type('text/html');
+   MP2 ? 1 : $r->send_http_header;
    $r->print($str);
-   return OK;
+   return MP2 ? Apache::OK : Apache::Constants::OK;
 }
 
 sub HashVariables {
